@@ -23,6 +23,11 @@ use colour::*;
 #[quit::main]
 fn main() {
     let config = dirs::config_dir().unwrap();
+    let mapm_config = Path::new(&config).join("mapm");
+    if !mapm_config.exists() {
+        fs::create_dir_all(&mapm_config)
+            .expect(&format!("Could not create directory {mapm_config:?}"));
+    }
     let profile: String;
     let profile_config_path = Path::new(&config).join("mapm").join("profile");
     if profile_config_path.is_file() {
@@ -44,23 +49,15 @@ fn main() {
         .join("problems")
         .join(&profile);
     if !problem_dir.is_dir() {
-        fs::create_dir_all(&problem_dir).expect(
-            &[
-                "Could not create directory `",
-                problem_dir.to_str().unwrap(),
-                "`",
-            ]
-            .concat(),
-        );
+        fs::create_dir_all(&problem_dir)
+            .expect(&format!("Could not create directory {problem_dir:?}"));
     }
 
     let template_dir = Path::new(&config).join("mapm").join("templates");
 
     if !template_dir.is_dir() {
-        fs::create_dir_all(&template_dir).expect(&format!(
-            "Could not create directory `{}`",
-            &template_dir.to_str().unwrap()
-        ));
+        fs::create_dir_all(&template_dir)
+            .expect(&format!("Could not create directory `{template_dir:?}`",));
     }
 
     let mut actions: Vec<(String, Vec<String>)> = Vec::new();
@@ -196,7 +193,7 @@ fn main() {
                             Command::new(&editor)
                                 .arg(&problem_path_str)
                                 .status()
-                                .expect(&["Failed to start `", &editor, "`"].concat());
+                                .expect(&format!("Failed to start `{editor}`"));
                         }
                         None => {
                             e_red_ln!("{}", msg::MISSING_EDIT_ARG);
